@@ -46,7 +46,7 @@
 step_intercept <- function(recipe, ..., role = "predictor",
                            trained = FALSE, name = "intercept", 
                            value = 1,
-                           skip = FALSE) {
+                           skip = FALSE, id = rand_id("intercept")) {
   if (length(list(...)) > 0)
     warning("Selectors are not used for this step.", call. = FALSE)
   if (!is.numeric(value))
@@ -61,23 +61,24 @@ step_intercept <- function(recipe, ..., role = "predictor",
       trained = trained,
       name = name,
       value = value,
-      skip = skip
+      skip = skip,
+      id = id
     )
   )
 }
 
-step_intercept_new <- function(role = "predictor", trained = FALSE,
-                               name = "intercept", value = 1,
-                               skip = FALSE) {
-  step(
-    subclass = "intercept",
-    role = role,
-    trained = trained,
-    name = name,
-    value = value,
-    skip = skip
-  )
-}
+step_intercept_new <- 
+  function(role, trained, name, value, skip, id) {
+    step(
+      subclass = "intercept",
+      role = role,
+      trained = trained,
+      name = name,
+      value = value,
+      skip = skip,
+      id = id
+    )
+  }
 
 #' @export
 prep.step_intercept <- function(x, training, info = NULL, ...) {
@@ -87,8 +88,8 @@ prep.step_intercept <- function(x, training, info = NULL, ...) {
 
 #' @importFrom tibble add_column
 #' @export
-bake.step_intercept <- function(object, newdata, ...) {
-  tibble::add_column(newdata, !!object$name := object$value, .before = TRUE)
+bake.step_intercept <- function(object, new_data, ...) {
+  tibble::add_column(new_data, !!object$name := object$value, .before = TRUE)
 }
 
 print.step_intercept <-
