@@ -13,6 +13,9 @@
 #' @param role Unused, include for consistency with other steps.
 #' @param trained A logical to indicate if the quantities for preprocessing
 #'   have been estimated. Again included for consistency.
+#' @param columns A character string of variable names that will
+#'  be populated (eventually) by the `terms` argument.
+#' @param id A character string that is unique to this step to identify it.
 #' @param skip A logical. Should the step be skipped when the
 #'  recipe is baked by [bake.recipe()]? While all operations are baked
 #'  when [prep.recipe()] is run, some operations may not be able to be
@@ -33,39 +36,49 @@
 #'   juice()
 #'
 #' @seealso [recipe()] [prep.recipe()] [bake.recipe()]
-step_naomit <- function(recipe, ..., role = NA, trained = FALSE, skip = FALSE) {
+step_naomit <- function(recipe, ..., role = NA, trained = FALSE, 
+                        columns = NULL, skip = FALSE,
+                        id = rand_id("naomit")) {
   add_step(
     recipe,
     step_naomit_new(
       terms = ellipse_check(...),
       role = role,
       trained = trained,
-      skip = skip
+      columns = columns,
+      skip = skip,
+      id = id
     )
   )
 }
 
-step_naomit_new <- function(terms = NULL, role = NA, trained = FALSE,
-                            skip = FALSE) {
+step_naomit_new <- function(terms, role, trained, columns, skip, id) {
   step(
     subclass = "naomit",
     terms = terms,
     role = role,
     trained = trained,
-    skip = skip
+    columns = columns,
+    skip = skip,
+    id = id
   )
 }
 
 #' @export
 prep.step_naomit <- function(x, training, info = NULL, ...) {
-  x$col_names <- terms_select(x$terms, info = info)
-  x$trained <- TRUE
-  x
+  step_naomit_new(
+    terms = x$terms,
+    role = x$role,
+    trained = TRUE,
+    columns = terms_select(x$terms, info = info),
+    skip = x$skip,
+    id = x$id
+  )
 }
 
 #' @export
-bake.step_naomit <- function(object, newdata, ...) {
-  tibble::as_tibble(tidyr::drop_na(newdata, object$col_names))
+bake.step_naomit <- function(object, new_data, ...) {
+  tibble::as_tibble(tidyr::drop_na(new_data, object$columns))
 }
 
 print.step_naomit <-
@@ -78,6 +91,9 @@ print.step_naomit <-
 
 #' @rdname step_naomit
 #' @param x A `step_naomit` object.
+#' @export
 tidy.step_naomit <- function(x, ...) {
-  simple_terms(x, ...)
+  res <-simple_terms(x, ...)
+  res$id <- x$id
+  res
 }
