@@ -43,26 +43,29 @@ step_rm <- function(recipe,
                     ...,
                     role = NA,
                     trained = FALSE,
-                    removals = NULL) {
+                    removals = NULL,
+                    skip = FALSE,
+                    id = rand_id("rm")) {
   add_step(recipe,
            step_rm_new(
-             terms = check_ellipses(...),
+             terms = ellipse_check(...),
              role = role,
              trained = trained,
-             removals = removals
+             removals = removals,
+             skip = skip,
+             id = id
            ))
 }
 
-step_rm_new <- function(terms = NULL,
-                        role = NA,
-                        trained = FALSE,
-                        removals = NULL) {
+step_rm_new <- function(terms, role, trained, removals, skip, id) {
   step(
     subclass = "rm",
     terms = terms,
     role = role,
     trained = trained,
-    removals = removals
+    removals = removals,
+    skip = skip,
+    id = id
   )
 }
 
@@ -73,15 +76,17 @@ prep.step_rm <- function(x, training, info = NULL, ...) {
     terms = x$terms,
     role = x$role,
     trained = TRUE,
-    removals = col_names
+    removals = col_names,
+    skip = x$skip,
+    id = x$id
   )
 }
 
 #' @export
-bake.step_rm <- function(object, newdata, ...) {
+bake.step_rm <- function(object, new_data, ...) {
   if (length(object$removals) > 0)
-    newdata <- newdata[, !(colnames(newdata) %in% object$removals)]
-  as_tibble(newdata)
+    new_data <- new_data[, !(colnames(new_data) %in% object$removals)]
+  as_tibble(new_data)
 }
 
 print.step_rm <-
@@ -106,4 +111,5 @@ print.step_rm <-
 
 #' @rdname step_rm
 #' @param x A `step_rm` object.
+#' @export
 tidy.step_rm <- tidy_filter
