@@ -1,8 +1,10 @@
 library(testthat)
 library(recipes)
-library(dimRed)
 data(biomass)
 
+context("ICA")
+
+
 biomass_tr <- biomass[biomass$dataset == "Training",]
 biomass_te <- biomass[biomass$dataset == "Testing",]
 
@@ -66,13 +68,17 @@ exp_comp <- structure(
 rownames(exp_comp) <- NULL
 
 test_that('correct ICA values', {
+  skip_if_not_installed("dimRed")
+  skip_if_not_installed("fastICA")
+  skip_if_not_installed("RSpectra")
+  
   ica_extract <- rec %>%
-    step_ica(carbon, hydrogen, oxygen, nitrogen, sulfur, num = 2)
+    step_ica(carbon, hydrogen, oxygen, nitrogen, sulfur, num_comp = 2, id = "")
 
   set.seed(12)
   ica_extract_trained <- prep(ica_extract, training = biomass_tr, verbose = FALSE)
 
-  ica_pred <- bake(ica_extract_trained, newdata = biomass_te, all_predictors())
+  ica_pred <- bake(ica_extract_trained, new_data = biomass_te, all_predictors())
   ica_pred <- as.matrix(ica_pred)
 
   rownames(ica_pred) <- NULL
@@ -83,11 +89,12 @@ test_that('correct ICA values', {
   tidy_exp_un <- tibble(
     terms = rep(vars, 2),
     value = rep(NA_real_, 2*5),
-    component = rep(c("IC1", "IC2"), 5)
+    component = rep(c("IC1", "IC2"), 5),
+    id = ""
   )
   expect_equal(tidy_exp_un, tidy(ica_extract, number = 1))
 
-  loadings <- getRotationMatrix(ica_extract_trained$steps[[1]]$res)
+  loadings <- dimRed::getRotationMatrix(ica_extract_trained$steps[[1]]$res)
   comps <- ncol(loadings)
   loadings <- as.data.frame(loadings)
   rownames(loadings) <- vars
@@ -97,16 +104,25 @@ test_that('correct ICA values', {
   tidy_exp_tr <- tibble(
     terms = tidy_exp_un$terms,
     value = loadings$values,
-    component = as.character(loadings$ind)
+    component = as.character(loadings$ind),
+    id = ""
   )
   expect_equal(tidy_exp_tr, tidy(ica_extract_trained, number = 1))
 
 })
 
 
+test_that('deprecated arg', {
+  
+  expect_message(
+    rec %>%
+      step_ica(carbon, hydrogen, oxygen, nitrogen, sulfur, num = 2)
+  )
+})
+
 test_that('printing', {
   ica_extract <- rec %>%
-    step_ica(carbon, hydrogen, num = 2)
+    step_ica(carbon, hydrogen, num_comp = 2)
   expect_output(print(ica_extract))
   expect_output(prep(ica_extract, training = biomass_tr, verbose = TRUE))
 })
