@@ -2,6 +2,9 @@ library(testthat)
 library(recipes)
 library(Matrix)
 
+context("Spare matrix format")
+
+
 ###################################################################
 
 data(okc)
@@ -24,15 +27,15 @@ rec <- recipe( ~ ., data = okc_tr) %>%
 ###################################################################
 
 test_that('correct types', {
-  bake_default <- bake(rec, newdata = okc_te, all_numeric())
+  bake_default <- bake(rec, new_data = okc_te, all_numeric())
   bake_sparse <-
     bake(rec,
-         newdata = okc_te,
+         new_data = okc_te,
          all_numeric(),
          composition = "dgCMatrix")
   bake_sparse_1d <-
     bake(rec,
-         newdata = okc_te,
+         new_data = okc_te,
          age,
          composition = "dgCMatrix")
   juice_default <- juice(rec, all_numeric())
@@ -57,6 +60,24 @@ test_that('correct types', {
 })
 
 test_that('bad args', {
-  expect_error(bake(rec, newdata = okc_te, composition = "dgCMatrix"))
+  expect_error(bake(rec, new_data = okc_te, composition = "dgCMatrix"))
   expect_error(juice(rec, composition = "dgCMatrix"))
 })
+
+test_that('issue 206 - NA values are kept when requesting matrix composition', {
+  df <- data.frame(x = factor(c("x", "x", "y")), x2 = c(NA, 1, NA))
+
+  rec <- recipe(x2 ~ ., data = df) %>%
+    step_dummy(x) %>%
+    prep(df)
+
+  res_mat <- bake(rec, df, composition = "matrix")
+  res_sparse <- bake(rec, df, composition = "dgCMatrix")
+
+  expect_equal(nrow(res_mat), 3)
+  expect_equal(nrow(res_sparse), 3)
+
+  expect_equal(as.vector(res_mat[,"x2"]), df$x2)
+  expect_equal(as.vector(res_sparse[,"x2"]), df$x2)
+
+})
